"use strict";
// Copyright IBM Corp. 2018,2019. All Rights Reserved.
// Node module: @loopback/example-rpc-server
// This file is licensed under the MIT License.
// License text available at https://opensource.org/licenses/MIT
Object.defineProperty(exports, "__esModule", { value: true });
exports.routeHandler = exports.rpcRouter = void 0;
const tslib_1 = require("tslib");
const body_parser_1 = tslib_1.__importDefault(require("body-parser"));
function rpcRouter(server) {
    const jsonParser = body_parser_1.default.json();
    server.expressServer.post('*', jsonParser, async (request, response) => {
        await routeHandler(server, request, response);
    });
}
exports.rpcRouter = rpcRouter;
async function routeHandler(server, request, response) {
    const ctrl = request.body.controller;
    const method = request.body.method;
    const input = request.body.input;
    let controller;
    try {
        controller = await server.get(`controllers.${ctrl}`);
        if (!controller[method]) {
            throw new Error(`No method was found on controller "${ctrl}" with name "${method}".`);
        }
    }
    catch (err) {
        sendErrResponse(response, err, 400);
        return;
    }
    try {
        response.send(await controller[method](input));
    }
    catch (err) {
        sendErrResponse(response, err, 500);
    }
}
exports.routeHandler = routeHandler;
function sendErrResponse(resp, 
// eslint-disable-next-line @typescript-eslint/no-explicit-any
send, statusCode) {
    resp.statusCode = statusCode;
    resp.send(send);
}
//# sourceMappingURL=rpc.router.js.map